@@ -1,9 +1,11 @@
-#!/usr/bin/perl -I../lib
+#!/usr/bin/perl
+
+use lib 'lib', '../lib';
 
 use Exception::Base;
 use Exception::Died '%SIG';
 
-eval { open $file, "z", "/badmodeexample" };
+eval { open my $file, "z", "/badmodeexample" };
 warn 'ref $@ = ', ref $@;
 warn '$@ = ', $@;
 if ($@) {
