@@ -1,7 +1,9 @@
-#!/usr/bin/perl -I../lib
+#!/usr/bin/perl
+
+use lib 'lib', '../lib';
 
 use Exception::Base 'Exception::Died';
 
-eval { open $file, "x", "/badmodeexample" };
+eval { open my $file, "x", "/badmodeexample" };
 warn "\$@ = $@";
 Exception::Died->throw( $@, message=>"cannot open" ) if $@;
