@@ -25,6 +25,6 @@ use Exception::Base max_arg_nums => 0, max_arg_len => 200, verbosity => 4,
 use Exception::Died verbosity => 4;
 use Exception::Assertion verbosity => 4;
 
-local $SIG{__WARN__} = sub { Exception::DiedTest::Warning->throw($_[0], ignore_level => 1) };
+local $SIG{__WARN__} = sub { Exception::DiedTest::Warning->throw( join('', @_), ignore_level => 1 ) };
 
 all_tests;
